Python in the browser, precompiled for fast, small code
=======================================================
**Monthly downloads from PyPi: 13,286**

![logo](http://www.transcrypt.org/illustrations/ruler_banner2.png "")

This package requires Python 3.6, install from the command prompt by typing:

*python -m pip install transcrypt*

or in several alternative ways as explained in the docs, which can be found at:

[http://www.transcrypt.org](http://www.transcrypt.org)

Features
========

- Precompiled into highly readable, efficient JavaScript, downloads kB's rather than MB's
- Multiple inheritance, optional operator overloading, metaclasses, properties, class and function decorators, hierarchical modules etc.
- Seamless integration with the universe of high-quality web-oriented JavaScript libraries, rather than the desktop-oriented Python ones
- Pure Python 3.6 syntax, using Python's native parser
- Debug directly from Python sourcecode, through integrated sourcemaps
- Generates JavaScript for humans, resembling the Python source line by line, optionally annotated with source line numbers
- Lightning fast JavaScript 5 and 6 code: call caching, for-loop optimization, in-line JavaScript etc.
- Integrated static typechecking and minification at the tip of a command line switch
- Also runs on top of node.js
- Extensive documentation with many code examples
- Apache 2.0 license
- Pip-install and go!

As can be seen below, the compiled code is highly readable and resembles the Python original:

![examplecode](http://www.transcrypt.org/illustrations/class_compare_doc.png "")
